==> hoteldruid-mod-nl_2.2.1-1.zip: nl/clienti.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "De datum is niet correct"; break;
case "Si deve inserire il tipo di tariffa":  	$messaggio = "U moet het tarief invoeren"; break;
case "tariffa":  				$messaggio = "tarief"; break;
case "Non è stato ancora inserito il prezzo della":	$messaggio = "U moet toch de prijs invoeren"; break;
case "per la settimana dal":  			$messaggio = "voor de week vanaf"; break;
case "per il giorno dal":  			$messaggio = "voor de dag vanaf"; break;
case "al":  					$messaggio = "naar"; break;
case "La settimana dal":  			$messaggio = "De week vanaf"; break;
case "Il giorno dal":  				$messaggio = "De dag vanaf"; break;
case "è piena":  				$messaggio = "is vol"; break;
case "è pieno":  				$messaggio = "is vol"; break;
case "persone":  				$messaggio = "personen"; break;
case "nato il":	  				$messaggio = "geboren op"; break;
case "CAP":  					$messaggio = "postcode"; break;
case "Telefono":  				$messaggio = "Telefoon°"; break;
case "2º telefono":  				$messaggio = "GSM°"; break;
case "3º telefono":  				$messaggio = "2de Telefoon°"; break;
case "Utilizza il cliente":  			$messaggio = "voor de gast"; break;
case "per la prenotazione":  			$messaggio = "voor de resevering"; break;
case "Modifica i dati del cliente":  		$messaggio = "Wijzig de gegevens van de gast"; break;
case "Inserisci un nuovo cliente":  		$messaggio = "Voeg een nieuwe gast"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "De achternaam van de gast is vereist"; break;
case "I dati del cliente":  			$messaggio = "Gegevens van de gast"; break;
case "sono stati inseriti":  			$messaggio = "zijn ingevoegd"; break;
case "Inserisci o modifica i dati di un cliente":	$messaggio = "Voeg in of wijzig de gegevens van de gast"; break;
case "Cognome":  				$messaggio = "Achternaam"; break;
case "nome":  					$messaggio = "naam"; break;
case "sesso":  					$messaggio = "geslacht"; break;
case "anno con 4 cifre":  			$messaggio = "jaar met 4 digits"; break;
case "Nazione":  				$messaggio = "Land"; break;
case "città":  					$messaggio = "Plaats"; break;
case "Via":  					$messaggio = "Straat"; break;
case "Piazza":  				$messaggio = "Plein"; break;
case "Vicolo":  				$messaggio = "Weg"; break;
case "Numero di telefono":  			$messaggio = "Telefoonnummer"; break;
case "Secondo telefono":  			$messaggio = "GSM"; break;
case "Terzo telefono":  			$messaggio = "tweede telefoon"; break;
case "Numero di fax":  				$messaggio = "Fax nummer"; break;
case "Seconda persona di riferimento":  	$messaggio = "Tweede referentie persoon"; break;
case "Inserisci i dati":  			$messaggio = "Voeg data in"; break;
case "Torna al menù principale":  		$messaggio = "Terug naar menu"; break;
case "Italia":  				$messaggio = ""; break;
case "sono stati modificati":  			$messaggio = "is gewijzigd"; break;
case "e":  					$messaggio = "en"; break;
case "Il numero di prenotazioni è sbagliato":	$messaggio = "Het aantal reserveringen is foutief"; break;
case "Aggiungi":  				$messaggio = "Voeg toe"; break;
case "Nº di tipologie da aggiungere":  		$messaggio = "Toe te voegen aantal typen"; break;
case "Non si è trovato nessun cliente chiamato":	$messaggio = "er zijn geen gasten genaamd"; break;
case "Il numero di persone è sbagliato":  	$messaggio = "Het aantal personen is fout"; break;
case "Continua":  				$messaggio = "ga verder"; break;
case "il":  					$messaggio = "the"; break;
case " a":  					$messaggio = " in"; break;
case "ln.":  					$messaggio = "ln."; break;
case "Il numero di settimane del costo aggiuntivo settimanale nº":	$messaggio = "The number of weeks of the weekly extra cost n°"; break;
case "Il numero di giorni del costo aggiuntivo giornaliero nº":	$messaggio = "The number of days of the daily extra cost n°"; break;
case "supera il numero totale di settimane della prenotazione":	$messaggio = "is bigger than the number of weeks of the reservation"; break;
case "supera il numero totale di giorni della prenotazione":	$messaggio = "is bigger than the number of days of the reservation"; break;
case "Si dovrà occupare almeno un periodo della regola di assegnazione 1":	$messaggio = "At least one period of the assignment rule 1 will have to be occupied"; break;
case "Si devono fare i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Movements that must be done in the periods of the <div style=\"display: inline; color: blue;\">assignment rule 1</div>"; break;
case "Sono stati fatti i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Movements that have been done in the periods of the <div style=\"display: inline; color: blue;\">assignment rule 1</div>"; break;
case "La prenotazione dal":  			$messaggio = "The reservation from"; break;
case "a nome di":  				$messaggio = "for Mr/Ms"; break;
case "Non si può procedere perchè la tabella prenotazioni è cambiata nel frattempo":	$messaggio = "Can't continue because the reservations table has changed meanwhile"; break;
case "Continua lo stesso":  			$messaggio = "Continue anyway"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "Non esistono clienti chiamati":  		$messaggio = "There are no clients called"; break;
case "nel database":  				$messaggio = "in the database"; break;
case "Inserisci i dati di un nuovo cliente":  	$messaggio = "Insert a new client's data"; break;
case "Esistono i seguenti clienti con un cognome uguale o simile":	$messaggio = "There are already these clients with the same or similar surname"; break;
case "Esistono i seguenti clienti con un cognome e nome uguale o simile":	$messaggio = "There are already these clients with the same or similar surname and name"; break;
case "nata il":	  				$messaggio = "born the"; break;
case "Data di nascita":  			$messaggio = "Birthdate"; break;
case "Viale":  					$messaggio = "Avenue"; break;
case "Piazzale":  				$messaggio = "Boulevard"; break;
case "non verrano modificati i dati specifici delle 2 persone di riferimento":	$messaggio = "data specific to the 2 reference people will not be changed"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "There are no periods in assignment rule 1 in which is allowed to insert reservations for user"; break;
case "I dati di un costo aggiuntivo sono errati":	$messaggio = "Data from and extra cost is wrong"; break;
case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":	$messaggio = "You can't insert more than one extra cost with percentage on total price per reservation"; break;
case "Non si puo inserire il costo aggiuntivo":	$messaggio = "The extra cost"; break;
case "in questo periodo":  			$messaggio = "can't be inserted in this period"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Choose the weeks to be applied for the extra cost"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Choose the days to be applied for the extra cost"; break;
case "Non si possono inserire altri costi":  	$messaggio = "You can't insert more costs"; break;
case "in questo periodo, già":  		$messaggio = "in this period, already"; break;
case "presenti":  				$messaggio = "present"; break;
case "Si deve inserire il numero delle persone per il costo aggiuntivo":	$messaggio = "The number of people must be inserted for the extra cost"; break;
case "Il costo aggiuntivo":  			$messaggio = "The extra cost"; break;
case "è incompatibile con la tariffa selezionata":	$messaggio = "is incompatible with selected rate"; break;
case "non può essere applicato":  		$messaggio = "can't be applied"; break;
case "regione":  				$messaggio = "region"; break;
case "Documento":  				$messaggio = "Document"; break;
case "scadenza":  				$messaggio = "expiration"; break;
case "Torna all'inserimento clienti":  		$messaggio = "Back to clients insertion"; break;
case "Annulla":  				$messaggio = "Cancel"; break;
case "Ospite della prenotazione":  		$messaggio = "Guest of reservation"; break;
case "tipologia":  				$messaggio = "type"; break;
case "Ospiti della prenotazione":  		$messaggio = "Guests of reservation"; break;
case "Altri ospiti":  				$messaggio = "Other guests"; break;
case "nato":  					$messaggio = "born"; break;
case "nata":  					$messaggio = "born"; break;
case "scade":  					$messaggio = "expires"; break;
case "cittadinanza":  				$messaggio = "nationality"; break;
case "città di nascita":  			$messaggio = "city of birth"; break;
case "reg./prov. di nascita":  			$messaggio = "region of birth"; break;
case "nazione di nascita":  			$messaggio = "nation of birth"; break;
case "Residenza":  				$messaggio = "Residency"; break;
case "reg./prov.":  				$messaggio = "region"; break;
case "nazione":  				$messaggio = "nation"; break;
case "rilasciato da":  				$messaggio = "released by"; break;
case "nazione di rilascio":  			$messaggio = "releasing nation"; break;
case "parentela":  				$messaggio = "relatedness"; break;
case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "with selected extra costs"; break;
case "I beni richiesti dal costo":  		$messaggio = "Goods needed by cost"; break;
case "non sono disponibili nell'inventario":  	$messaggio = "are not available in the inventory"; break;
case "Si deve inserire il numero delle persone per questa tariffa":	$messaggio = "The number of people must be inserted for this rate"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "lo sconto è sbagliato":  			$messaggio = "the discount is wrong"; break;
case "la caparra è sbagliata":  		$messaggio = "the deposit is wrong"; break;
case "soprannome":  				$messaggio = "nickname"; break;
case "le commissioni sono sbagliate":  		$messaggio = "commissions are wrong"; break;
case "lingua":  				$messaggio = "language"; break;
case "non può essere moltiplicato per più di":	$messaggio = "can not be multiplied by more than"; break;
case "La tariffa richiesta è chiusa in questo periodo":	$messaggio = "The requested rate is closed in this period"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-nl_3.0.8-1.zip: nl/clienti.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "De datum is niet correct"; break;
case "Si deve inserire il tipo di tariffa":  	$messaggio = "U moet het tarief invoeren"; break;
case "tariffa":  				$messaggio = "tarief"; break;
case "Non è stato ancora inserito il prezzo della":	$messaggio = "U moet toch de prijs invoeren"; break;
case "per la settimana dal":  			$messaggio = "voor de week vanaf"; break;
case "per il giorno dal":  			$messaggio = "voor de dag vanaf"; break;
case "al":  					$messaggio = "naar"; break;
case "La settimana dal":  			$messaggio = "De week vanaf"; break;
case "Il giorno dal":  				$messaggio = "De dag vanaf"; break;
case "è piena":  				$messaggio = "is vol"; break;
case "è pieno":  				$messaggio = "is vol"; break;
case "persone":  				$messaggio = "personen"; break;
case "nato il":	  				$messaggio = "geboren op"; break;
case "CAP":  					$messaggio = "postcode"; break;
case "Telefono":  				$messaggio = "Telefoon°"; break;
case "2º telefono":  				$messaggio = "GSM°"; break;
case "3º telefono":  				$messaggio = "2de Telefoon°"; break;
case "Utilizza il cliente":  			$messaggio = "voor de gast"; break;
case "per la prenotazione":  			$messaggio = "voor de resevering"; break;
case "Modifica i dati del cliente":  		$messaggio = "Wijzig de gegevens van de gast"; break;
case "Inserisci un nuovo cliente":  		$messaggio = "Voeg een nieuwe gast"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "De achternaam van de gast is vereist"; break;
case "I dati del cliente":  			$messaggio = "Gegevens van de gast"; break;
case "sono stati inseriti":  			$messaggio = "zijn ingevoegd"; break;
case "Inserisci o modifica i dati di un cliente":	$messaggio = "Voeg in of wijzig de gegevens van de gast"; break;
case "Cognome":  				$messaggio = "Achternaam"; break;
case "nome":  					$messaggio = "naam"; break;
case "sesso":  					$messaggio = "geslacht"; break;
case "anno con 4 cifre":  			$messaggio = "jaar met 4 digits"; break;
case "Nazione":  				$messaggio = "Land"; break;
case "città":  					$messaggio = "Plaats"; break;
case "Via":  					$messaggio = "Straat"; break;
case "Piazza":  				$messaggio = "Plein"; break;
case "Vicolo":  				$messaggio = "Weg"; break;
case "Numero di telefono":  			$messaggio = "Telefoonnummer"; break;
case "Secondo telefono":  			$messaggio = "GSM"; break;
case "Terzo telefono":  			$messaggio = "tweede telefoon"; break;
case "Numero di fax":  				$messaggio = "Fax nummer"; break;
case "Seconda persona di riferimento":  	$messaggio = "Tweede referentie persoon"; break;
case "Inserisci i dati":  			$messaggio = "Voeg data in"; break;
case "Torna al menù principale":  		$messaggio = "Terug naar menu"; break;
case "Italia":  				$messaggio = ""; break;
case "sono stati modificati":  			$messaggio = "is gewijzigd"; break;
case "e":  					$messaggio = "en"; break;
case "Il numero di prenotazioni è sbagliato":	$messaggio = "Het aantal reserveringen is foutief"; break;
case "Aggiungi":  				$messaggio = "Voeg toe"; break;
case "Nº di tipologie da aggiungere":  		$messaggio = "Toe te voegen aantal typen"; break;
case "Non si è trovato nessun cliente chiamato":	$messaggio = "er zijn geen gasten genaamd"; break;
case "Il numero di persone è sbagliato":  	$messaggio = "Het aantal personen is fout"; break;
case "Continua":  				$messaggio = "ga verder"; break;
case "il":  					$messaggio = "the"; break;
case " a":  					$messaggio = " in"; break;
case "ln.":  					$messaggio = "ln."; break;
case "Clienti":  				$messaggio = "Clients"; break;
case "Il numero di settimane del costo aggiuntivo settimanale nº":	$messaggio = "The number of weeks of the weekly extra cost n°"; break;
case "Il numero di giorni del costo aggiuntivo giornaliero nº":	$messaggio = "The number of days of the daily extra cost n°"; break;
case "supera il numero totale di settimane della prenotazione":	$messaggio = "is bigger than the number of weeks of the reservation"; break;
case "supera il numero totale di giorni della prenotazione":	$messaggio = "is bigger than the number of days of the reservation"; break;
case "Si dovrà occupare almeno un periodo della regola di assegnazione 1":	$messaggio = "At least one period of the assignment rule 1 will have to be occupied"; break;
case "Si devono fare i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Movements that must be done in the periods of the <div style=\"display: inline; color: blue;\">assignment rule 1</div>"; break;
case "Sono stati fatti i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Movements that have been done in the periods of the <div style=\"display: inline; color: blue;\">assignment rule 1</div>"; break;
case "La prenotazione dal":  			$messaggio = "The reservation from"; break;
case "a nome di":  				$messaggio = "for Mr/Ms"; break;
case "Non si può procedere perchè la tabella prenotazioni è cambiata nel frattempo":	$messaggio = "Can't continue because the reservations table has changed meanwhile"; break;
case "Continua lo stesso":  			$messaggio = "Continue anyway"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "Non esistono clienti chiamati":  		$messaggio = "There are no clients called"; break;
case "nel database":  				$messaggio = "in the database"; break;
case "Inserisci i dati di un nuovo cliente":  	$messaggio = "Insert a new client's data"; break;
case "Esistono i seguenti clienti con un cognome uguale o simile":	$messaggio = "There are already these clients with the same or similar surname"; break;
case "Esistono i seguenti clienti con un cognome e nome uguale o simile":	$messaggio = "There are already these clients with the same or similar surname and name"; break;
case "nata il":	  				$messaggio = "born the"; break;
case "Data di nascita":  			$messaggio = "Birthdate"; break;
case "Viale":  					$messaggio = "Avenue"; break;
case "Piazzale":  				$messaggio = "Boulevard"; break;
case "non verrano modificati i dati specifici delle 2 persone di riferimento":	$messaggio = "data specific to the 2 reference people will not be changed"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "There are no periods in assignment rule 1 in which is allowed to insert reservations for user"; break;
case "I dati di un costo aggiuntivo sono errati":	$messaggio = "Data from and extra cost is wrong"; break;
case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":	$messaggio = "You can't insert more than one extra cost with percentage on total price per reservation"; break;
case "Non si puo inserire il costo aggiuntivo":	$messaggio = "The extra cost"; break;
case "in questo periodo":  			$messaggio = "can't be inserted in this period"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Choose the weeks to be applied for the extra cost"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Choose the days to be applied for the extra cost"; break;
case "Non si possono inserire altri costi":  	$messaggio = "You can't insert more costs"; break;
case "in questo periodo, già":  		$messaggio = "in this period, already"; break;
case "presenti":  				$messaggio = "present"; break;
case "Si deve inserire il numero delle persone per il costo aggiuntivo":	$messaggio = "The number of people must be inserted for the extra cost"; break;
case "Il costo aggiuntivo":  			$messaggio = "The extra cost"; break;
case "è incompatibile con la tariffa selezionata":	$messaggio = "is incompatible with selected rate"; break;
case "non può essere applicato":  		$messaggio = "can't be applied"; break;
case "regione":  				$messaggio = "region"; break;
case "Documento":  				$messaggio = "Document"; break;
case "scadenza":  				$messaggio = "expiration"; break;
case "Torna all'inserimento clienti":  		$messaggio = "Back to clients insertion"; break;
case "Annulla":  				$messaggio = "Cancel"; break;
case "Ospite della prenotazione":  		$messaggio = "Guest of reservation"; break;
case "tipologia":  				$messaggio = "type"; break;
case "Ospiti della prenotazione":  		$messaggio = "Guests of reservation"; break;
case "Altri ospiti":  				$messaggio = "Other guests"; break;
case "nato":  					$messaggio = "born"; break;
case "nata":  					$messaggio = "born"; break;
case "scade":  					$messaggio = "expires"; break;
case "cittadinanza":  				$messaggio = "nationality"; break;
case "città di nascita":  			$messaggio = "city of birth"; break;
case "reg./prov. di nascita":  			$messaggio = "region of birth"; break;
case "nazione di nascita":  			$messaggio = "nation of birth"; break;
case "Residenza":  				$messaggio = "Residency"; break;
case "reg./prov.":  				$messaggio = "region"; break;
case "nazione":  				$messaggio = "nation"; break;
case "rilasciato da":  				$messaggio = "released by"; break;
case "nazione di rilascio":  			$messaggio = "releasing nation"; break;
case "parentela":  				$messaggio = "relatedness"; break;
case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "with selected extra costs"; break;
case "I beni richiesti dal costo":  		$messaggio = "Goods needed by cost"; break;
case "non sono disponibili nell'inventario":  	$messaggio = "are not available in the inventory"; break;
case "Si deve inserire il numero delle persone per questa tariffa":	$messaggio = "The number of people must be inserted for this rate"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "lo sconto è sbagliato":  			$messaggio = "the discount is wrong"; break;
case "la caparra è sbagliata":  		$messaggio = "the deposit is wrong"; break;
case "soprannome":  				$messaggio = "nickname"; break;
case "le commissioni sono sbagliate":  		$messaggio = "commissions are wrong"; break;
case "lingua":  				$messaggio = "language"; break;
case "non può essere moltiplicato per più di":	$messaggio = "can not be multiplied by more than"; break;
case "La tariffa richiesta è chiusa in questo periodo":	$messaggio = "The requested rate is closed in this period"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Si deve inserire almeno una persona che possa essere ospite principale":	$messaggio = "You must insert at least one person that can be main guest"; break;
case "non si sono potuti usare":  		$messaggio = "It was not possible to use"; break;
case "letti aggiuntivi perchè non c'era nessuna tipologia di persone con quel numero":	$messaggio = "extra beds as there was no people type with that number"; break;
case "E-mail":  				$messaggio = "E-mail"; break;
case "Seconda e-mail":  			$messaggio = "Second e-mail"; break;
case "E-mail certificata (PEC) o codice destinatario":	$messaggio = "Certified e-mail"; break;
case "email":  					$messaggio = "email"; break;
case "2ª email":  				$messaggio = "2nd email"; break;
case "PEC/codice":  				$messaggio = "certified email"; break;
case "Per questa tariffa si deve inserire un numero minimo di":	$messaggio = "For this rate you have to insert at least"; break;
case "persona":  				$messaggio = "person"; break;
case "Usa il cliente della prenotazione originale":	$messaggio = "Use the client from the original reservation"; break;
case "2° cognome":  				$messaggio = "2nd surname"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
